TEQCreport(sampleName = "", targetsName = "", referenceName = "", destDir = "TEQCreport", reads = get.reads(), targets = get.targets(), Offset = 0, pairedend = FALSE, genome = c(NA, "hg19", "hg18"), genomesize, k=c(1, 2, 3, 5, 10, 20), covthreshold = 8, CovUniformityPlot = FALSE, CovTargetLengthPlot = FALSE, CovGCPlot = FALSE, duplicatesPlot = FALSE, baits = get.baits(), WigFiles = FALSE, saveWorkspace = FALSE, figureFormat = c("jpeg", "png", "tiff"))RangedData table containing positions
of sequenced reads, or call to get.reads to read in positions from a bed or BAM fileRangedData table containing positions
of target regions, or call to get.targets to read in positions from a bed fileOffset bases on both sides to targeted regions and potentially
collapse resulting overlapping target regionsTRUE, data will be considered to be paired-end data, i.e. reads will be "merged" to read
pairs, and chromosome bar plot, specificity, enrichment and duplicate analysis (if selected) will be
based on read pairs rather than on single readsk-values for which to show fraction
of target bases with coverage >= k in 'Sensitivity' table. Passed to covered.kcoverage.histTRUE, a coverage uniformity plot is created,
see coverage.uniformityTRUE, coverage vs target length plots are created,
see coverage.targetlength.plot TRUE, a coverage vs GC content plot is created,
see coverage.GCTRUE, a duplicates barplot is created,
see duplicates.barplotRangedData table holding the hybridization probe
("bait") positions and sequences, or call to get.baits to read in
positions from a bed file. Only needed if CovGCPlot = TRUE.TRUE, wiggle files with per-base coverage are created for each chromosomeTRUE, an R workspace with objects reads, targets and
output of coverage.target and reads2pairs
(in case pairedend = TRUE) are saved in destDir to be available for further analysesdestDir.
The report can be viewed by opening destDir/index.html in a web browser. Images are saved in
destDir/image. Wiggle files (in case WigFiles = TRUE) are saved in
destDir/wiggle. A table with general target coverage statistics, a table with average coverage values per target, a table with cumulative fractions of targeted bases with certain coverage and the R workspace
containing R objects for potential further analysis (in case saveWorkspace = TRUE)
are saved in destDir.get.reads, get.targets, fraction.target, fraction.reads.target,
coverage.target, readsPerTarget, reads2pairs,
covered.k, coverage.hist, coverage.uniformity,
coverage.targetlength.plot, coverage.GC, get.baits,
make.wigfiles## get reads and targets files
exptPath <- system.file("extdata", package="TEQC")
readsfile <- file.path(exptPath, "ExampleSet_Reads.bed")
targetsfile <- file.path(exptPath, "ExampleSet_Targets.bed")
## create report
## Not run:
# TEQCreport(sampleName="Test Sample", targetsName="Human Exome", referenceName="Human Genome",
# destDir="report", reads=get.reads(readsfile, skip=0, idcol=4),
# targets=get.targets(targetsfile, skip=0), genome="hg19")## End(Not run)
Run the code above in your browser using DataLab